# frozen_string_literal: true

require 'action_view'
require 'action_view/helpers'
require 'sidekiq/cli'
require 'sidekiqtui/version'
require 'tty-box'
require 'tty-screen'
require 'tty-table'

include ActionView::Helpers::DateHelper

module Sidekiqtui
  module_function

  def run
    configure

    box = TTY::Box.frame(
      width: TTY::Screen.width,
      height: TTY::Screen.height,
      title: { top_left: 'Scheduled Jobs', bottom_right: Sidekiqtui::VERSION }
    ) do
      ss = Sidekiq::ScheduledSet.new
      jobs = ss.map do |job|
        [
          "in #{time_ago_in_words(job.at)}",
          job.queue,
          job.item['class'],
          job.args.join(', ')
        ]
      end.reverse

      table = TTY::Table.new(
        %w[When Queue Job Arguments],
        jobs
      )
      table.render(:unicode)
    end

    print box
  end

  def configure
    Sidekiq.configure_server do |config|
      config.logger = nil
    end
  end
end
